@@ -1,16 +1,17 @@
 """
 Unit test file.
 """
+
+import atexit
 import os
 import shutil
 import subprocess
 import unittest
-import atexit
 
 from create_python_cmd.createapp import do_create_python_app
 
 HERE = os.path.abspath(os.path.dirname(__file__))
-REMOVE_AFTER_TEST = True
+REMOVE_AFTER_TEST = False
 
 
 def read_utf8(path: str) -> str:
@@ -40,39 +41,42 @@ class CreateAppTester(unittest.TestCase):
             app_keywords="myapp test",
             version="1.2.3",
             github_url="https://github.com/author/my-app",
-            command_name="mytestcommand",
+            command_name="my-app",
             cwd=outdir,
             chmod_scripts=False,
         )
         self.assertTrue(os.path.exists(outdir))
         self.assertTrue(os.path.exists(os.path.join(outdir, "pyproject.toml")))
         self.assertTrue(os.path.exists(os.path.join(outdir, "setup.py")))
-        setup_py_lines: list[str] = read_utf8(os.path.join(outdir, "setup.py")).splitlines()
+        setup_py_lines: list[str] = read_utf8(
+            os.path.join(outdir, "setup.py")
+        ).splitlines()
         self.assertIn('KEYWORDS = "myapp test"', setup_py_lines)
         self.assertTrue(os.path.exists(os.path.join(outdir, "src", "my_app")))
         self.assertTrue(os.path.exists(os.path.join(outdir, "src", "my_app", "cli.py")))
-        self.assertTrue(os.path.exists(os.path.join(outdir, "src", "my_app", "__init__.py")))
+        self.assertTrue(
+            os.path.exists(os.path.join(outdir, "src", "my_app", "__init__.py"))
+        )
         self.assertTrue(os.path.exists(os.path.join(outdir, "tests")))
         self.assertTrue(os.path.exists(os.path.join(outdir, "tests", "test_cli.py")))
         self.assertTrue(os.path.exists(os.path.join(outdir, "tox.ini")))
+        self.assertTrue(os.path.exists(os.path.join(outdir, ".gitignore")))
         os.chdir(outdir)
 
         cmds = [
-            "pip install -e .",
-            "pip install -r requirements.testing.txt",
+            "bash install",
+            "uv pip install -r requirements.testing.txt",
             "black src",
             "black tests",
-            "python tests/test_cli.py",
-            "pylint src tests",
-            "flake8 src tests",
-            "mypy src tests",
+            "bash lint",
+            "bash test",
         ]
         assert os.path.exists(os.path.join(outdir, "lint"))
         env_with_current_dir = os.environ.copy()
-        os_sep = ";" if os.name == "nt" else ":"
-        env_with_current_dir["PATH"] = f"{outdir}{os_sep}{env_with_current_dir['PATH']}"
+        env_with_current_dir.pop("IN_ACTIVATED_ENV", None)
         for cmd in cmds:
-            rtn = subprocess.call(cmd, env=env_with_current_dir, shell=True)
+            print(f"Running command: {cmd} in {outdir}")
+            rtn = subprocess.call(cmd, env=env_with_current_dir, shell=True, cwd=outdir)
             self.assertEqual(0, rtn, f"Command failed: {cmd}")
 
 
